@@ -37,6 +37,7 @@ AptInterface::AptInterface(MainWindow* w_)
 	iError = tr("Undefined error");
 
 	getRepositories();
+	iNumAutoUpdates = 0;
 }
 
 AptInterface::~AptInterface()
@@ -154,6 +155,7 @@ void AptInterface::procFinished(int exitCode, QProcess::ExitStatus exitStatus)
 
 		if( lastMode == ModeReadInfo )
 		{
+			iNumAutoUpdates = 0;
 			if( !parseAptCacheOutput() ) {
 				iMainWindow->operationFinished(lastMode, false, iError);
 				return;
@@ -530,11 +532,16 @@ bool AptInterface::writeRepositories(QStringList repos)
 
 bool AptInterface::needRepoRefresh()
 {
+	if( iNumAutoUpdates > 0 )
+		return false;
+
 	QFile own("/root/.fapman/repos.list");
 	QFile ham("/etc/apt/sources.list.d/hildon-application-manager.list");
 
-	if( own.size() != ham.size() )
+	if( own.size() != ham.size() ) {
+		iNumAutoUpdates++;
 		return true;
+	}
 
 	QFileInfo a("/root/.fapman/lastupdate");
 	QFileInfo b("/home/user/.hildon-application-manager/last-update");
@@ -554,8 +561,10 @@ bool AptInterface::needRepoRefresh()
 			<< bDate.toString("dd.MM.yyyy hh:mm").toStdString() << "  "
 			<< QDateTime::currentDateTime().toString("dd.MM.yyyy hh:mm").toStdString() << std::endl;
 */
-	if( aDate < QDateTime::currentDateTime() && bDate < QDateTime::currentDateTime() )
+	if( aDate < QDateTime::currentDateTime() && bDate < QDateTime::currentDateTime() ) {
+		iNumAutoUpdates++;
 		return true;
+	}
 
 	return false;
 }
