@@ -30,11 +30,11 @@ dimmer::dimmer(QWidget *parent) :
 	iLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	iLabel->setAlignment(Qt::AlignCenter);
 	iLayout->addWidget(iLabel);
-	QProgressBar* p = new QProgressBar(this);
-	p->setMinimum(0);
-	p->setMaximum(0);
-	iLayout->addWidget(p);
 	iBusy = false;
+	iTimer = new QTimer(this);
+	connect(iTimer,SIGNAL(timeout()),this,SLOT(repaint()));
+	iAnim = 0;
+	iAnimDir = 1;
 	hide();
 }
 
@@ -46,7 +46,21 @@ void dimmer::paintEvent(QPaintEvent *)
 	painter.setPen(dim);
 	painter.setBrush(dim);
 	painter.drawRect(this->rect());
-	show();
+
+	painter.setBrush( QApplication::palette().color(QPalette::Highlight) );
+
+	int step = 15;
+	int animMax = 10;
+
+	painter.drawEllipse(QPoint(this->rect().left()+(this->rect().width()/2-(animMax*step)/2)+iAnim*step,
+							   this->rect().height()-this->rect().height()/4), 10, 10);
+
+	iAnim += iAnimDir;
+	if( iAnim>animMax )
+		iAnimDir=-1;
+	if( iAnim==-1 )
+		iAnimDir=1;
+
 }
 
 void dimmer::resizeEvent(QResizeEvent *)
@@ -61,10 +75,15 @@ void dimmer::dim(QString title, QString message)
 	iBusy = true;
 	iLabel->setText("<font color=\"white\"><b><u>" + title + "</u></b><br><br>" + message + "</font>");
 	show();
+	iAnim = 0;
+	iAnimDir = 1;
+	iTimer->start(250);
 }
 
 void dimmer::undim()
 {
 	iBusy = false;
+	iTimer->stop();
 	hide();
 }
+
