@@ -40,11 +40,12 @@ private:
 	QBoxLayout* iLayout;
 	QLabel* iLabel;
 	bool iBusy;
+	QTimer* iTimer;
 
-signals:
-
-public slots:
+	int iAnim;
+	int iAnimDir;
 
 };
 
 #endif // DIMMER_H
+
